@@ -33,7 +33,6 @@ from construct.core import Struct
 from construct.lib.containers import Container
 from construct import Const, Int64ul
 
-
 from cmd import Cmd
 from six import PY3
 from pprint import pprint
@@ -137,7 +136,7 @@ class AFCClient(object):
     def __init__(self, lockdown=None, serviceName="com.apple.afc", service=None, udid=None, logger=None):
         self.logger = logger or logging.getLogger(__name__)
         self.serviceName = serviceName
-        self.lockdown = lockdown if lockdown else LockdownClient(udid=udid)
+        self.lockdown = lockdown or LockdownClient(udid=udid)
         self.service = service if service else self.lockdown.start_service(self.serviceName)
         self.packet_num = 0
 
@@ -358,6 +357,20 @@ class AFCClient(object):
         d = self.file_write(h, data)
         self.file_close(h)
 
+    def set_upload_dir(self, path, afc_path):
+        if os.path.isdir(path):
+            self.make_directory(afc_path)
+            dir_list = os.listdir(path)
+            for _dir in dir_list:
+                _path = f'{path}/{_dir}'
+                if os.path.isdir(_path):
+                    self.set_upload_dir(_path, f'{afc_path}/{_dir}')
+                else:
+                    with open(_path, "rb") as f:
+                        self.set_file_contents(f'{afc_path}/{_dir}', f.read())
+        else:
+            raise Exception(f"{path} must be a folder")
+
     def dir_walk(self, dirname):
         dirs = []
         files = []
@@ -443,6 +456,8 @@ class AFCShell(Cmd):
 
     def do_rm(self, p):
         f = self.afc.get_file_info(self.curdir + "/" + p)
+        if not f:
+            return
         if f['st_ifmt'] == 'S_IFDIR':
             d = self.afc.remove_directory(self.curdir + "/" + p)
         else:
@@ -544,8 +559,3 @@ class AFCCrashLog(AFCClient):
         super(AFCCrashLog, self).__init__(lockdown, serviceName="com.apple.crashreportcopymobile", udid=udid)
 
 
-if __name__ == "__main__":
-    import sys
-
-    logging.basicConfig(level=logging.INFO)
-    AFCShell().cmdloop("Hello iPhone!")
